@@ -3,6 +3,7 @@ from kafka import KafkaConsumer
 from redis import Redis
 from time import sleep, time
 import requests
+import logging
 
 from .helper import Helper
 
@@ -37,16 +38,24 @@ class Translator:
   def redis_consume (self, metrics: list, redis_host: str, redis_password: str):
     instance = metrics[0].properties['instance']
 
+    logging.debug("%s new metric(s) received for host '%s'", len(metrics), instance)
+
     conn = Redis(host=redis_host, password=redis_password)
     conn.rpush(instance, Helper.concatenate_metrics(metrics))
     conn.close()
 
   def prod (self, redis_host='localhost', redis_password='root', kafka_host='localhost', kafka_port=9093, kafka_topic='general'):
-    consumer = KafkaConsumer(kafka_topic, bootstrap_servers=[ '%s:%i' % (kafka_host, kafka_port) ], value_deserializer=lambda m: Helper.concatenate_metrics_arrays(list(map(self._translation_function, m.decode('ascii').split('\n'))) if m else []))
-    
-    for msg in consumer: 
-      if msg.value: 
-        self.redis_consume(msg.value, redis_host, redis_password)
+    logging.info("Kafka properties: host=%s, port=%s, topic=%s", kafka_host, kafka_port, kafka_topic)
+    logging.info("Redis properties: host=%s, password=%s", redis_host, redis_password)
+
+    try:
+      consumer = KafkaConsumer(kafka_topic, bootstrap_servers=[ '%s:%i' % (kafka_host, kafka_port) ], value_deserializer=lambda m: Helper.concatenate_metrics_arrays(list(map(self._translation_function, m.decode('ascii').split('\n'))) if m else []))
+      
+      for msg in consumer: 
+        if msg.value: 
+          self.redis_consume(msg.value, redis_host, redis_password)
+    except Exception as e:
+      logging.error(e)
 
   def pull (self, endpoint: str, interval: int = 15, redis_host='localhost', redis_password: str = 'root'):
     while True:
